@@ -1,7 +1,7 @@
 /* devices.h */
 /*
 Copyright (C) 2005 Jean-Baptiste jb_dul@yahoo.com
-Copyright (C) 2007 Fabian Nowak <timystery@arcor.de>
+Copyright (C) 2007 , 2008Fabian Nowak <timystery@arcor.de>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -24,13 +24,9 @@ Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #include <glib.h>
 
 #include "helpers.h"
-
-#ifdef DEBUG
-#undef DEBUG
-#endif
-#ifdef DEBUG_TRACE
-#undef DEBUG_TRACE
-#endif
+/* #include "mount-plugin.h" */
+/* extern t_disk_display ; */
+/* People, learn to program in an object-oriented way! */
 
 /**
  * An enum.
@@ -77,7 +73,8 @@ typedef struct s_disk {
     char *device;                 /**< Device name, e.g. /dev/cdrom */
     char *mount_point;             /**< Device mount point, e.g. /mnt/cdrom */
     t_mount_info *  mount_info; /**< NULL if not mounted */
-    t_deviceclass dc;             /**<Ddevice classification */
+    /*`t_disk_display *disk_display; */ /* People, learn to program in an object-oriented way! */
+    t_deviceclass dc;             /**< Device classification */
 } t_disk;
 
 
@@ -96,29 +93,30 @@ char * get_size_human_readable(float size);
  * @param on_mount_cmd    Command to execute after successfully mounting the device
  * @param mount_command    Command to use for mounting the device, still containing placeholders like \%d and \%m.
  * @param eject            Whether to inject the device before mounting.
- * @return                Exit status of the mount command
+ * @param use_sudo         Whether to use sudo to run the mount command.
  */
-void disk_mount (t_disk *pdisk, char *on_mount_cmd, char* mount_command, gboolean eject);
+void disk_mount (t_disk *pdisk, char *on_mount_cmd, char* mount_command, gboolean eject, gboolean use_sudo);
 
 
 /**
  * Unmount a t_disk.
- * @param pdisk            Disk to mount
+ * @param pdisk            Disk to umount
  * @param umount_command    Command to use for unmounting the device, still containing placeholders like \%d and \%m.
- * @param synchronous    Whether to execute the command synchronously to the program itself thus waiting for the output
+ * @param show_message_dialog Whether to show a dialog upon successful umount for device removal
  * @param eject            Whether to eject the device after unmounting.
- * @return                 Exit status of the mount command
+ * @param use_sudo         Whether to use sudo to run the umount command.
  */
-int disk_umount (t_disk *pdisk, char* umount_command, gboolean synchronous, gboolean eject);
+void disk_umount (t_disk *pdisk, char* umount_command, gboolean show_message_dialog, gboolean eject, gboolean use_sudo);
 
 
 /**
  * Fill a GPtrArray with pointers on struct t_disk containing infos on devices
  * and theoretical mount point. Uses setfsent() and getfsent().
  * @param include_NFSs    TRUE if remote file systems should also be displayed.
+ * @param showed_fstab_dialog Pointer to whether dialog has already been shown before
  * @return                GPtrArray with t_disks
  */
-GPtrArray * disks_new (gboolean include_NFSs) ;
+GPtrArray * disks_new (gboolean include_NFSs, gboolean *showed_fstab_dialog) ;
 
 
 /**
@@ -163,10 +161,10 @@ t_disk * disks_search (GPtrArray * pdisks, char * device);
 
 /**
  * Lookup given mountpoint and device for exclusion
- * @param excluded_FSs	Pointer to array of excluded filesystems
- * @param mountpoint	Mountpoint of device to search for
- * @param device		Original device path to search for
- * @return				TRUE, if device is to be excluded
+ * @param excluded_FSs  Pointer to array of excluded filesystems
+ * @param mountpoint    Mountpoint of device to search for
+ * @param device        Original device path to search for
+ * @return              TRUE, if device is to be excluded
  */
 gboolean exclude_filesystem (GPtrArray *excluded_FSs, gchar *mountpoint, gchar *device);
 
@@ -189,11 +187,20 @@ t_deviceclass disk_classify (char* device, char *mountpoint);
 
 /**
  * Checks, if disk is still mounted
- * @param disk			device name or mountpoint to check
- * @return				true, if mounted, else false.
+ * @param disk          device name or mountpoint to check
+ * @return              true, if mounted, else false.
  */
 gboolean disk_check_mounted (const char *disk);
 
+void mount_info_print(t_mount_info * mount_info);
+t_mount_info * mount_info_new (float size, float used, float avail, unsigned int percent, char * type, char * mounted_on);
+void mount_info_free(t_mount_info * * mount_info);
+void disk_print (t_disk * pdisk);
+char * shorten_disk_name (const char *dev);
+t_disk * disk_new (const char * dev, const char * mountpoint);
+void disk_free(t_disk **pdisk);
+void disks_free_mount_info(GPtrArray * pdisks);
+
 #endif /* _DEVICES_H_ */
 
 
